@@ -1,8 +1,14 @@
-#' Estimate Standardized Regression Coefficients and Sampling Covariance Matrix Assuming Multivariate Normality
+#' Estimate Standardized Regression Coefficients
+#' and Sampling Covariance Matrix Assuming Multivariate Normality
 #'
 #' @author Ivan Jacob Agaloos Pesigan
 #'
-#' @return Returns an object of class `betaSandwich` which is a list with the following elements:
+#' @details
+#' `BetaN()` assumes multivariate normality.
+#' `BetaHC()` is recommended in most situations.
+#'
+#' @return Returns an object of class `betaSandwich`
+#' which is a list with the following elements:
 #' \describe{
 #'   \item{call}{Function call.}
 #'   \item{type}{Standard error type.}
@@ -23,49 +29,21 @@
 #' vcov(std)
 #' confint(std, level = 0.95)
 #' @export
-#' @importFrom methods is
-#' @importFrom stats cov hatvalues
 #' @family Beta Sandwich Functions
 #' @keywords betaSandwich
 BetaN <- function(object) {
-  stopifnot(
-    methods::is(
-      object,
-      "lm"
-    )
-  )
-  y <- object$model[, 1]
-  x <- stats::model.matrix(object)
-  x[, 1] <- y
-  varnames <- colnames(x)
-  xnames <- varnames[-1]
-  dims <- dim(x)
-  n <- dims[1]
-  k <- dims[2]
-  p <- k - 1
-  df <- n - k
-  sigmacap <- stats::cov(x)
-  sigma <- sqrt(diag(sigmacap))
-  rhocap <- .RhoofSigma(
-    sigmacap,
-    q = 1 / sigma
-  )
-  betastar <- .BetaStarofRho(
-    rhocap = rhocap,
-    k = k
-  )
-  names(betastar) <- xnames
+  input <- .ProcessLM(object)
   jcap <- .JacobianVechSigmaWRTThetaStar(
-    betastar = betastar,
-    sigmay = sigma[1],
-    sigmax = sigma[-1],
-    rhocapx = rhocap[2:k, 2:k, drop = FALSE],
-    q = p + 1 + 0.5 * p * (p + 1),
-    p = p
+    betastar = input$betastar,
+    sigmay = input$sigma[1],
+    sigmax = input$sigma[-1],
+    rhocapx = input$rhocap[2:input$k, 2:input$k, drop = FALSE],
+    q = input$p + 1 + 0.5 * input$p * (input$p + 1),
+    p = input$p
   )
   gammacap_mvn <- .GammaN(
-    sigmacap = sigmacap,
-    pinv_of_dcap = .PInvDmat(.DMat(k))
+    sigmacap = input$sigmacap,
+    pinv_of_dcap = .PInvDmat(.DMat(input$k))
   )
   avcov <- .ACovN(
     jcap = jcap,
@@ -73,17 +51,17 @@ BetaN <- function(object) {
   )
   vcov <- .CovN(
     acov = avcov,
-    n = n
-  )[1:p, 1:p, drop = FALSE]
-  colnames(vcov) <- rownames(vcov) <- xnames
+    n = input$n
+  )[1:input$p, 1:input$p, drop = FALSE]
+  colnames(vcov) <- rownames(vcov) <- input$xnames
   out <- list(
     call = match.call(),
     type = "mvn",
-    beta = betastar,
+    beta = input$betastar,
     vcov = vcov,
-    n = n,
-    p = p,
-    df = df
+    n = input$n,
+    p = input$p,
+    df = input$df
   )
   class(out) <- c(
     "betasandwich",
